/* 
 * File:   nautilus-metadata-extractor.h
 * Author: yelo3
 *
 * Created on 13 luglio 2008, 2.45
 */

#ifndef _NAUTILUS_METADATA_EXTRACTOR_H
#define	_NAUTILUS_METADATA_EXTRACTOR_H

#ifdef	__cplusplus
extern "C" {
#endif

#include "nautilus-metadata-info.h"
#include "nautilus-metadata-attribute.h"

// you can use this struct to associate the tag that uses the extractor (extractor_attribute)
// to the tag that uses your extension (metadata_attribute)
// and the function that must be used to "transform" the extracted value into the value you want to put in the
// Metadata

// the Metadata type can be accessed using:
//	- metadata_set() //thread safe
//	- metadata_get() //thread safe
//	- metadata_foreach() //thread safe
// this function must extract metadata from file_uri and insert it into the Metadata struct
void extract_metadata_file(Metadata* metadata, const char* file_uri, const char* mime_type);
// this function must extract metadata from directory_uri and insert it into the Metadata struct
// it is not a problem if the body of this function blank (directories hardly ever have metadata)
void extract_metadata_directory(Metadata* metadata, const char* directory_uri);

// returns: the maximun number of contemporary running threads
// a value < 1 is ignored
// each thread executes either extract_metadata_file or extract_metadata_directory
int get_max_thread_number(void);

// this function is called when the extension is registered to nautilus
void initialize_extractor(void);
// this function is called whene the extension is un-registered from nautilus
void shutdown_extractor(void);

// returns a list of NautilusAttributeDescriptor that must be filled with the attributes that
// the extractor can handle
// the caller will call g_list_free() so you must not store the list outside the function
GList* get_supported_attributes();

// this function must return the extension name, that must be unique in all nautilus-
// an example "NautilusMetadataExtensionDummy"
const char* get_extension_name();

#ifdef	__cplusplus
}
#endif

#endif	/* _NAUTILUS_METADATA_EXTRACTOR_H */

